package com.aucma.dms.service;

import com.aucma.dms.domain.DmsBaseMaintStandard;

import java.util.List;

/**
 * 保养标准信息Service接口
 * 
 * @author xins
 * @date 2024-01-05
 */
public interface IDmsBaseMaintStandardService 
{
    /**
     * 查询保养标准信息
     * 
     * @param maintStandardId 保养标准信息主键
     * @return 保养标准信息
     */
    public DmsBaseMaintStandard selectDmsBaseMaintStandardByMaintStandardId(Long maintStandardId);

    /**
     * 查询保养标准信息列表
     * 
     * @param dmsBaseMaintStandard 保养标准信息
     * @return 保养标准信息集合
     */
    public List<DmsBaseMaintStandard> selectDmsBaseMaintStandardList(DmsBaseMaintStandard dmsBaseMaintStandard);

    /**
     * 新增保养标准信息
     * 
     * @param dmsBaseMaintStandard 保养标准信息
     * @return 结果
     */
    public int insertDmsBaseMaintStandard(DmsBaseMaintStandard dmsBaseMaintStandard);

    /**
     * 修改保养标准信息
     * 
     * @param dmsBaseMaintStandard 保养标准信息
     * @return 结果
     */
    public int updateDmsBaseMaintStandard(DmsBaseMaintStandard dmsBaseMaintStandard);

    /**
     * 批量删除保养标准信息
     * 
     * @param maintStandardIds 需要删除的保养标准信息主键集合
     * @return 结果
     */
    public int deleteDmsBaseMaintStandardByMaintStandardIds(Long[] maintStandardIds);

    /**
     * 删除保养标准信息信息
     * 
     * @param maintStandardId 保养标准信息主键
     * @return 结果
     */
    public int deleteDmsBaseMaintStandardByMaintStandardId(Long maintStandardId);
}
