package com.aucma.dms.controller;

import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.core.page.TableDataInfo;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.dms.domain.DmsBaseMaintStandard;
import com.aucma.dms.service.IDmsBaseMaintStandardService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;




/**
 * 保养标准信息Controller
 * 
 * @author xins
 * @date 2024-01-05
 */
@RestController
@RequestMapping("/dms/standard")
public class DmsBaseMaintStandardController extends BaseController
{
    @Autowired
    private IDmsBaseMaintStandardService dmsBaseMaintStandardService;

    /**
     * 查询保养标准信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:standard:list')" )
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseMaintStandard dmsBaseMaintStandard)
    {
        startPage();
        List<DmsBaseMaintStandard> list = dmsBaseMaintStandardService.selectDmsBaseMaintStandardList(dmsBaseMaintStandard);
        return getDataTable(list);
    }

    /**
     * 导出保养标准信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:standard:export')" )
    ////@Log(title = "保养标准信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseMaintStandard dmsBaseMaintStandard)
    {
        List<DmsBaseMaintStandard> list = dmsBaseMaintStandardService.selectDmsBaseMaintStandardList(dmsBaseMaintStandard);
        ExcelUtil<DmsBaseMaintStandard> util = new ExcelUtil<DmsBaseMaintStandard>(DmsBaseMaintStandard.class);
        util.exportExcel(response, list, "保养标准信息数据");
    }

    /**
     * 查询保养标准列表
     */
    @GetMapping("/getMaintStandardlist")
    public AjaxResult getMaintStandardlist(DmsBaseMaintStandard dmsBaseMaintStandard)
    {
        List<DmsBaseMaintStandard> list = dmsBaseMaintStandardService
                .selectDmsBaseMaintStandardList(dmsBaseMaintStandard);
        return success(list);
    }

   /**
     * 获取保养标准信息详细信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:standard:query')" )
    @GetMapping(value = "/{maintStandardId}")
    public AjaxResult getInfo(@PathVariable("maintStandardId") Long maintStandardId)
    {
        return success(dmsBaseMaintStandardService.selectDmsBaseMaintStandardByMaintStandardId(maintStandardId));
    }


    /**
     * 新增保养标准信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:standard:add')" )
    ////@Log(title = "保养标准信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseMaintStandard dmsBaseMaintStandard)
    {
        return toAjax(dmsBaseMaintStandardService.insertDmsBaseMaintStandard(dmsBaseMaintStandard));
    }

    /**
     * 修改保养标准信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:standard:edit')" )
    ////@Log(title = "保养标准信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseMaintStandard dmsBaseMaintStandard)
    {
        return toAjax(dmsBaseMaintStandardService.updateDmsBaseMaintStandard(dmsBaseMaintStandard));
    }

    /**
     * 删除保养标准信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:standard:remove')" )
    ////@Log(title = "保养标准信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{maintStandardIds}")
    public AjaxResult remove(@PathVariable Long[] maintStandardIds)
    {
        return toAjax(dmsBaseMaintStandardService.deleteDmsBaseMaintStandardByMaintStandardIds(maintStandardIds));
    }
}
